<p align="center">
    <img width="100" src="https://rawcdn.githack.com/yetone/figure_bed/master/olo_logo.png" >
</p>

# 

<p align="center">
    <a href="https://www.python.org">
        <img alt="Support Python Version" src="https://img.shields.io/badge/Python-2.7-brightgreen.svg">
    </a>
    <a href="https://www.python.org">
        <img alt="Support Python Version" src="https://img.shields.io/badge/Python-3.6-brightgreen.svg">
    </a>
    <a href="https://travis-ci.org/yetone/olo">
        <img alt="Build Status" src="https://travis-ci.org/yetone/olo.svg?branch=master">
    </a>
    <a href="https://codecov.io/gh/yetone/olo">
        <img src="https://codecov.io/gh/yetone/olo/branch/master/graph/badge.svg" />
    </a>
</p>

<p align="center">
    ORM.
</p>

<p align="center">
    <a href="https://yetone.github.io/olo/">查看文档 📖</a>
</p>

## TL;DR

<img src="https://rawcdn.githack.com/yetone/figure_bed/master/olo1.svg" />
